# vcdisk
![](coverage.svg)

Rotation curves of thick truncated galaxy disks

A minimal python package to solve Poisson's equation and and to compute the circular
velocity curve of a truncated disk with non-zero thickness and arbitrary radial
density profile. This implements the algorithm of
[Casertano (1983)](https://ui.adsabs.harvard.edu/abs/1983MNRAS.203..735C)
